<?php
// +-----------------------------------------------------------------------+
// | Plugin Name : Export Image metadata                                   |
// | Plugin Version : 0.1                                                  |
// | Plugin Author: Eric                                                   |
// | Plugin Description :                                                  |
// | Ce module est base sur le module existant pour le telechargement,     |
// | cette version permet le telechargement sur plusieurs pages.           |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.               '                                                  |
// +-----------------------------------------------------------------------+

class ExportImageMetadata
{
  private $use_exiftool, $use_exiv2, $use_whole_desc;

  function ExportImageMetadata($use_exiftool_p, $use_exiv2_p, $use_whole_desc_p)
  {
	  $this->use_exiftool = $use_exiftool_p;
	  $this->use_exiv2 = $use_exiv2_p;
	  $this->use_whole_desc = $use_whole_desc_p;
  }

  public function image_properties_to_file($toolPath, $destPath)
  { 		
	$exiftoolPath = ""; $exiv2Path = "";
	if ($this->use_exiftool)
	{
		$exiftoolPath = $destPath ."/writeTagsToIptcWithExifTool.cmd";
		$fp_exiftool = $this->open_create_file($exiftoolPath);
	}
	if ($this->use_exiv2)
	{
		$exiv2Path = $destPath ."/writeTagsToIptcWithExiv2.cmd";
		$fp_exiv2 = $this->open_create_file($exiv2Path);
	}

	$datas = $this->get_image_properties();
	$nbr_tag = 0;

	while ($row = mysql_fetch_row($datas)) // row to avoid conflict with name
	{		
		$name = $this->decode_html_string_to_unicode($row[0]);
		$description = $this->decode_html_string_to_unicode($row[1]);
		$author = $this->decode_html_string_to_unicode($row[2]);
		//$date_creation = $this->decode_html_string_to_unicode($row[3]);
		$tags = $this->decode_html_string_to_unicode($row[4]);
		//str_replace('"', '\"', $this->decode_html_string_to_unicode($row[4]));
		$image_path = $row[5];

		if (file_exists($image_path))
		{
			$nbr_tag = $nbr_tag + 1;

			$exiftoolCmd = $this->init_exif_tool_cmd_name($toolPath, "exiftool");
			$exiv2Cmd = $this->init_exif_tool_cmd_name($toolPath, "exiv2");
			$exiv2Cmd .=  " -k";

			if (strlen($name) > 0)
			{
				$exiv2Cmd .= " -M\"set Iptc.Application2.ObjectName ".$name."\"";
				$exiftoolCmd .= " -IPTC:ObjectName=\"".$name."\"";
			}
			if (strlen($description) > 0)
			{	
							
				$exiv2Cmd .= " -M\"set Iptc.Application2.Caption ".$description."\"";
				$exiftoolCmd .= " -IPTC:Caption-Abstract=\"".$description."\"";
			}
			if (strlen($author) > 0)
			{
				$exiv2Cmd .= " -M\"set Iptc.Application2.Writer ".$author."\"";
				$exiftoolCmd .= " -IPTC:Writer-Editor=\"".$author."\"";
			}	
			if (strlen($tags) > 0)			
			{
				$exiv2Cmd .= " -M\"add Iptc.Application2.Keywords ".$tags."\"";
				$exiftoolCmd .= " -IPTC:Keywords=\"".$tags."\"";
			}
			$exiv2Cmd .= " " .realpath(PHPWG_ROOT_PATH.$image_path);
			$exiftoolCmd .= " " .realpath(PHPWG_ROOT_PATH.$image_path);

			if ($this->use_exiftool)
			{	
				fwrite($fp_exiftool, $exiftoolCmd."\n");
			}
			if ($this->use_exiv2)
			{
				fwrite($fp_exiv2, $exiv2Cmd."\n");
			}
		}
	}


	if ($this->use_exiftool)
	{
		$this->close_file($nbr_tag, $fp_exiftool);
	}
	if ($this->use_exiftool)
	{
		$this->close_file($nbr_tag, $fp_exiv2);
	}
	return $nbr_tag;
  }

  // IO function
  private function open_create_file($destPath)
  {
	// prepare output file
	if(file_exists($destPath))
	{
		//chmod($conf['ScriptTagsFiles'], 0777);
		unlink($destPath);
	}
       	touch($destPath);
	return fopen($destPath,"w");
  }

  private function close_file($nbr_tag, $fp)
  {
	if ($nbr_tag > 0)
	{
		fwrite($fp,"\n");
	}
	fclose($fp);
  }

  private function init_exif_tool_cmd_name($toolPath, $toolName)
  {
	return (file_exists($toolPath) && strpos($toolPath, $toolName) !== false) ? "\"".$toolPath."\"" : $toolName;
  }

  // description explode
  private function explode_description($description)
  {
	if ($this->use_whole_desc)
	{
		return $description;
	}
	// consider current language
	
	// look for the [lang=] tag, and take only the desc between the tags.
	//strpos
  }

  // html function
  private function decode_html_string_to_unicode($string) 
  {
	if (isset($string) && strlen($string) > 0)
	{
		$string = html_entity_decode(trim($string), ENT_QUOTES, 'UTF-8'); //ISO-8859-15');
		$string = stripslashes($string);
	}
	else $string = "";
	return($string);
  } 

  // data access
  private function get_image_properties() 
  {
	// get direct properties and tags, even if no tags, with either name, comment or tags not null
	$img_query = 'SELECT img.name, img.comment, img.author, img.date_creation, GROUP_CONCAT(tags.name), img.path
		FROM '.IMAGES_TABLE.' AS img
		LEFT OUTER JOIN '.IMAGE_TAG_TABLE.' AS img_tag ON img_tag.image_id = img.id
		LEFT OUTER JOIN '.TAGS_TABLE.' AS tags ON tags.id = img_tag.tag_id
		WHERE ( LENGTH(img.name) > 0 OR LENGTH(img.comment) > 0 OR LENGTH(img.author) > 0 OR LENGTH(tags.name) > 0 )  
		GROUP BY img.id, img.name, img.comment, img.author, img.path
		ORDER BY  img.id ASC; ';
	
	return pwg_query($img_query);
  }
}
